@@ -4,6 +4,9 @@
 Rtree provides Python bindings to libspatialindex for quick
 hyperrectangular intersection queries.
 """
-__version__ = '0.9.7'
 
-from .index import Rtree, Index  # noqa
+from __future__ import annotations
+
+__version__ = "1.3.0"
+
+from .index import Index, Rtree  # noqa
